# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Quant, Unknowns

# Discovered Generic TypeVars:
T = TypeVar("T")
from .Application import IApplication
from .Engine import IGraphicsCanvas, IReportContext
from .Template import HorizontalAlign, IDataBinding, IReportTemplate

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.DataSource

class CustomCommand(
    Agilent.MassHunter.ReportBuilder.DataSource.ICustomCommand
):  # Class
    def __init__(
        self, label: str, tooltip: str, command: System.Windows.Input.ICommand
    ) -> None: ...

    Command: System.Windows.Input.ICommand  # readonly
    Label: str  # readonly
    Tooltip: str  # readonly

class CustomCommandGroup(
    Agilent.MassHunter.ReportBuilder.DataSource.ICustomCommandGroup
):  # Class
    def __init__(
        self,
        label: str,
        commands: List[Agilent.MassHunter.ReportBuilder.DataSource.ICustomCommand],
    ) -> None: ...

    Label: str  # readonly

    def GetCommands(
        self, app: IApplication
    ) -> List[Agilent.MassHunter.ReportBuilder.DataSource.ICustomCommand]: ...

class DataSourceDesignerType(System.IDisposable):  # Class
    def GetType(self, designerTypeName: str) -> System.Type: ...
    @staticmethod
    def GetTypes() -> Iterable[str]: ...
    @staticmethod
    def UninstallDesigners(name: str) -> None: ...
    @staticmethod
    def SetDesignerFolder(name: str, type: str, folder: str) -> None: ...
    @staticmethod
    def GetDesignerDefinitionFolder() -> str: ...
    @staticmethod
    def GetDesignerType(
        type: str,
    ) -> Agilent.MassHunter.ReportBuilder.DataSource.DataSourceDesignerType: ...
    @staticmethod
    def GetDisplayName(type: str, ci: System.Globalization.CultureInfo) -> str: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def InstallDesigners(
        name: str, items: List[Agilent.MassHunter.ReportBuilder.DataSource.DesignerItem]
    ) -> None: ...

class DataSourceGraphicsEnumValue(
    Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceGraphicsEnumValue
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, value_: str, displayText: str) -> None: ...

    DisplayText: str
    Value: str

class DataSourceGraphicsParameter(
    Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceGraphicsParameter
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        name: str,
        category: str,
        displayName: str,
        parameterType: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType,
        acceptsFieldValue: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterAcceptsFieldValue,
    ) -> None: ...
    @overload
    def __init__(
        self,
        name: str,
        category: str,
        displayName: str,
        parameterType: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType,
        acceptsFieldValue: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterAcceptsFieldValue,
        enumValues: List[
            Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceGraphicsEnumValue
        ],
    ) -> None: ...

    AcceptsFieldValue: (
        Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterAcceptsFieldValue
    )
    Category: str
    Description: str
    DisplayName: str
    EnumValues: List[
        Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceGraphicsEnumValue
    ]
    HasCustomEditor: bool
    Name: str
    ParameterType: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType

    def GetCustomEditor(
        self, application: IApplication, editorBaseType: System.Type
    ) -> Any: ...

class DefaultDataSource(
    Agilent.MassHunter.ReportBuilder.DataSource.IDataSource
):  # Class
    def __init__(self) -> None: ...
    def DrawGraphics(
        self,
        canvas: IGraphicsCanvas,
        x: float,
        y: float,
        width: float,
        height: float,
        name: str,
        parameters: List[System.Collections.Generic.KeyValuePair[str, Any]],
    ) -> None: ...
    def GetFieldCaption(self, dataName: str, fieldName: str) -> str: ...
    def Select(
        self, context: IReportContext, dataBinding: IDataBinding
    ) -> List[Any]: ...
    def LocalizeFieldValue(self, dataName: str, fieldName: str, value_: Any) -> str: ...
    def GetFieldFormat(self, dataName: str, fieldName: str) -> str: ...

class DefaultDataSourceDesigner(
    System.IDisposable, Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceDesigner
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, dataset: System.Data.DataSet) -> None: ...

    DataSourceType: System.Type  # readonly
    DisplayName: str  # readonly
    Name: str  # readonly

    def GetFieldNames(self, dataName: str) -> List[str]: ...
    def GetDataNames(self) -> List[str]: ...
    def Dispose(self) -> None: ...
    def GetCustomUI(self) -> T: ...

class DesignerDefinition:  # Class
    def __init__(self) -> None: ...

    Designers: List[Agilent.MassHunter.ReportBuilder.DataSource.DesignerItem]

class DesignerItem(System.Xml.Serialization.IXmlSerializable):  # Class
    def __init__(self) -> None: ...

    Folder: str
    Name: str
    Type: str

    def SetDisplayName(self, culture: str, displayName: str) -> None: ...
    def GetSchema(self) -> System.Xml.Schema.XmlSchema: ...
    def GetDisplayName(self, culture: System.Globalization.CultureInfo) -> str: ...
    def WriteXml(self, writer: System.Xml.XmlWriter) -> None: ...
    def ReadXml(self, reader: System.Xml.XmlReader) -> None: ...

class FieldFormat:  # Struct
    def __init__(
        self, format: Agilent.MassHunter.ReportBuilder.DataSource.FieldFormat
    ) -> None: ...

    FixedFormat: str
    HorizontalAlign: HorizontalAlign
    UseFieldFormat: bool

class GraphicsParameterAcceptsFieldValue(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Both: (
        Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterAcceptsFieldValue
    ) = ...  # static # readonly
    FieldValueOnly: (
        Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterAcceptsFieldValue
    ) = ...  # static # readonly
    ValueOnly: (
        Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterAcceptsFieldValue
    ) = ...  # static # readonly

class GraphicsParameterType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Boolean: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType = (
        ...
    )  # static # readonly
    Color: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType = (
        ...
    )  # static # readonly
    Custom: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType = (
        ...
    )  # static # readonly
    Double: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType = (
        ...
    )  # static # readonly
    Enum: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType = (
        ...
    )  # static # readonly
    Int: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType = (
        ...
    )  # static # readonly
    String: Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType = (
        ...
    )  # static # readonly

class ICustomCommand(object):  # Interface
    Command: System.Windows.Input.ICommand  # readonly
    Label: str  # readonly
    Tooltip: str  # readonly

class ICustomCommandGroup(object):  # Interface
    Label: str  # readonly

    def GetCommands(
        self, app: IApplication
    ) -> List[Agilent.MassHunter.ReportBuilder.DataSource.ICustomCommand]: ...

class ICustomUI(object):  # Interface
    def CanExecuteSystemCommand(
        self, app: IApplication, systemCommand: str, parameter: Any, canExecute: bool
    ) -> bool: ...
    def ExecuteSystemCommand(
        self, app: IApplication, systemCommand: str, parameter: Any
    ) -> bool: ...
    def GetCustomCommandGroups(
        self, app: IApplication
    ) -> List[Agilent.MassHunter.ReportBuilder.DataSource.ICustomCommandGroup]: ...

class IDataSource(object):  # Interface
    def DrawGraphics(
        self,
        canvas: IGraphicsCanvas,
        x: float,
        y: float,
        width: float,
        height: float,
        name: str,
        parameters: List[System.Collections.Generic.KeyValuePair[str, Any]],
    ) -> None: ...
    def GetFieldCaption(self, dataName: str, fieldName: str) -> str: ...
    def Select(
        self, context: IReportContext, dataBinding: IDataBinding
    ) -> List[Any]: ...
    def LocalizeFieldValue(self, dataName: str, fieldName: str, value_: Any) -> str: ...
    def GetFieldFormat(self, dataName: str, fieldName: str) -> str: ...

class IDataSourceDesigner(System.IDisposable):  # Interface
    DataSourceType: System.Type  # readonly

    def GetFieldNames(self, dataName: str) -> List[str]: ...
    def GetDataNames(self) -> List[str]: ...
    def GetCustomUI(self) -> T: ...

class IDataSourceGraphicsEdit(object):  # Interface
    def GetGraphicsNames(self) -> List[str]: ...
    def GetDisplayName(self, name: str) -> str: ...
    def GetParameters(
        self, name: str
    ) -> List[
        Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceGraphicsParameter
    ]: ...

class IDataSourceGraphicsEnumValue(object):  # Interface
    DisplayText: str  # readonly
    Value: str  # readonly

class IDataSourceGraphicsParameter(object):  # Interface
    AcceptsFieldValue: (
        Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterAcceptsFieldValue
    )  # readonly
    Category: str  # readonly
    Description: str  # readonly
    DisplayName: str  # readonly
    EnumValues: List[
        Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceGraphicsEnumValue
    ]  # readonly
    HasCustomEditor: bool  # readonly
    Name: str  # readonly
    ParameterType: (
        Agilent.MassHunter.ReportBuilder.DataSource.GraphicsParameterType
    )  # readonly

    def GetCustomEditor(
        self, application: IApplication, editorBasetype: System.Type
    ) -> Any: ...

class IDataSourceTableFormat(object):  # Interface
    def DefaultFieldFormat(
        self,
        dataName: str,
        fieldName: str,
        format: Agilent.MassHunter.ReportBuilder.DataSource.FieldFormat,
    ) -> bool: ...

class IReportPreview(object):  # Interface
    def GeneratePreview(
        self,
        templatePath: str,
        template: IReportTemplate,
        parameterFile: str,
        outputPath: str,
    ) -> None: ...
    def SetupPreview(
        self, parameterPath: str, parent: System.Windows.Window, alwaysShowUI: bool
    ) -> bool: ...

class IValidateTemplate(object):  # Interface
    def ValidateTemplate(
        self,
        context: Agilent.MassHunter.ReportBuilder.DataSource.ValidateTemplateContext,
        template: IReportTemplate,
        application: IApplication,
    ) -> bool: ...

class ValidateTemplateContext(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    OpenTemplate: (
        Agilent.MassHunter.ReportBuilder.DataSource.ValidateTemplateContext
    ) = ...  # static # readonly
    SaveTemplate: (
        Agilent.MassHunter.ReportBuilder.DataSource.ValidateTemplateContext
    ) = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import collections, zlib

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: System.util

class FilterStream(System.IDisposable, System.IO.Stream):  # Class
    def __init__(self, s: System.IO.Stream) -> None: ...

    CanRead: bool  # readonly
    CanSeek: bool  # readonly
    CanWrite: bool  # readonly
    Length: int  # readonly
    Position: int

    def Read(self, buffer: List[int], offset: int, count: int) -> int: ...
    def Write(self, buffer: List[int], offset: int, count: int) -> None: ...
    def Flush(self) -> None: ...
    def WriteByte(self, value_: int) -> None: ...
    def ReadByte(self) -> int: ...
    def SetLength(self, value_: int) -> None: ...
    def Close(self) -> None: ...
    def Seek(self, offset: int, origin: System.IO.SeekOrigin) -> int: ...

class ListIterator(Generic[T]):  # Class
    def __init__(self, col: List[T]) -> None: ...
    def Next(self) -> T: ...
    def Remove(self) -> None: ...
    def Previous(self) -> T: ...
    def HasNext(self) -> bool: ...

class Properties:  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly
    def __getitem__(self, key: str) -> str: ...
    def __setitem__(self, key: str, value_: str) -> None: ...
    Keys: Dict.KeyCollection[str, str]  # readonly

    def GetEnumerator(self) -> Dict.Enumerator[str, str]: ...
    def Load(self, inStream: System.IO.Stream) -> None: ...
    def Add(self, key: str, value_: str) -> None: ...
    def AddAll(self, col: System.util.Properties) -> None: ...
    def ContainsKey(self, key: str) -> bool: ...
    def Clear(self) -> None: ...
    def Remove(self, key: str) -> str: ...

class PushbackStream(System.IDisposable, System.util.FilterStream):  # Class
    def __init__(self, s: System.IO.Stream) -> None: ...
    def Read(self, buffer: List[int], offset: int, count: int) -> int: ...
    def ReadByte(self) -> int: ...
    def Unread(self, b: int) -> None: ...

class RectangleJ:  # Class
    @overload
    def __init__(self, x: float, y: float, width: float, height: float) -> None: ...
    @overload
    def __init__(self, rect: iTextSharp.text.Rectangle) -> None: ...

    OUT_BOTTOM: int = ...  # static # readonly
    OUT_LEFT: int = ...  # static # readonly
    OUT_RIGHT: int = ...  # static # readonly
    OUT_TOP: int = ...  # static # readonly

    Height: float
    Width: float
    X: float
    Y: float

    def Intersection(self, r: System.util.RectangleJ) -> System.util.RectangleJ: ...
    def Add(self, rect: System.util.RectangleJ) -> None: ...
    def Outcode(self, x: float, y: float) -> int: ...
    def IsEmpty(self) -> bool: ...
    def IntersectsLine(self, x1: float, y1: float, x2: float, y2: float) -> bool: ...

class StringTokenizer:  # Class
    @overload
    def __init__(self, str: str) -> None: ...
    @overload
    def __init__(self, str: str, delim: str) -> None: ...
    @overload
    def __init__(self, str: str, delim: str, retDelims: bool) -> None: ...
    def HasMoreTokens(self) -> bool: ...
    @overload
    def NextToken(self, delim: str) -> str: ...
    @overload
    def NextToken(self) -> str: ...
    def CountTokens(self) -> int: ...

class Util:  # Class
    @staticmethod
    def CompareToIgnoreCase(s1: str, s2: str) -> int: ...
    @staticmethod
    def GetStandartEnUSLocale() -> System.Globalization.CultureInfo: ...
    @staticmethod
    def GetArrayHashCode(a: List[T]) -> int: ...
    @staticmethod
    def Max(array: List[T]) -> T: ...
    @staticmethod
    def EqualsIgnoreCase(s1: str, s2: str) -> bool: ...
    @staticmethod
    def AreEqual(
        s1: System.Collections.Generic.Stack[T], s2: System.Collections.Generic.Stack[T]
    ) -> bool: ...
    @staticmethod
    def ArraysAreEqual(a: List[T], b: List[T]) -> bool: ...
    @staticmethod
    def USR(op1: int, op2: int) -> int: ...
    @staticmethod
    def Min(array: List[T]) -> T: ...
    @staticmethod
    def compare(f1: float, f2: float) -> int: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import CustomAttributes, Notification, Storage, Utilities

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.OpenLab.Framework.Common

class AsyncHelpers:  # Class
    @staticmethod
    def Yield() -> System.Threading.Tasks.Task[None]: ...
    @overload
    @staticmethod
    def RunCancelableAsync(
        cancellationToken: System.Threading.CancellationToken,
        task: System.Threading.Tasks.Task[None],
        sleepTime: int = ...,
    ) -> System.Threading.Tasks.Task[None]: ...
    @overload
    @staticmethod
    def RunCancelableAsync(
        cancellationToken: System.Threading.CancellationToken,
        task: System.Threading.Tasks.Task[T],
        sleepTime: int = ...,
    ) -> System.Threading.Tasks.Task[T]: ...
    @overload
    @staticmethod
    def RunSync(task: System.Func[System.Threading.Tasks.Task[None]]) -> None: ...
    @overload
    @staticmethod
    def RunSync(
        task: System.Func[System.Threading.Tasks.Task[None]],
        setStopAction: System.Action[System.Action, bool],
    ) -> None: ...
    @overload
    @staticmethod
    def RunSync(task: System.Func[System.Threading.Tasks.Task[T]]) -> T: ...
    @overload
    @staticmethod
    def RunSync(
        task: System.Func[System.Threading.Tasks.Task[T]],
        setStopAction: System.Action[System.Action, bool],
    ) -> T: ...

class AsyncTaskManager(System.IDisposable):  # Class
    CancellationToken: System.Threading.CancellationToken  # readonly
    Instance: Agilent.OpenLab.Framework.Common.AsyncTaskManager  # static # readonly

    def Start(self, action: System.Action) -> System.Threading.Tasks.Task[None]: ...
    def Wait(self, taskId: int, timeout: int = ...) -> bool: ...
    @staticmethod
    def Reset() -> None: ...
    def Remove(self, taskId: int) -> None: ...
    def Dispose(self) -> None: ...
    def AbortAll(self) -> None: ...

class DateTimeExtensions:  # Class
    DateFormatSpecificationStringForStandardFormat: str  # static # readonly
    DateFormatStringForStandardFormat: str  # static # readonly
    FormatStringForCurrentCultureWithGmtOffset: str  # static # readonly
    FormatStringForStandardFormat: str  # static # readonly

    @staticmethod
    def NormalizeDateTimeKind(dateTime: System.DateTime) -> System.DateTime: ...
    @staticmethod
    def ToStringForCurrentCultureWithGmtOffset(dateTime: System.DateTime) -> str: ...
    @staticmethod
    def ToStringUsingStandardFormat(dateTime: System.DateTime) -> str: ...

class NotificationException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, inner: System.Exception) -> None: ...
    @overload
    def __init__(self, innerException: System.Exception) -> None: ...

class SearchException(
    Agilent.OpenLab.Framework.Common.StorageException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, inner: System.Exception) -> None: ...
    @overload
    def __init__(self, innerException: System.Exception) -> None: ...

class StorageException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, inner: System.Exception) -> None: ...
    @overload
    def __init__(self, innerException: System.Exception) -> None: ...

class StorageFileNotFoundException(
    Agilent.OpenLab.Framework.Common.StorageException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, inner: System.Exception) -> None: ...
    @overload
    def __init__(self, innerException: System.Exception) -> None: ...

class StorageNotAvailableException(
    Agilent.OpenLab.Framework.Common.StorageException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, inner: System.Exception) -> None: ...
    @overload
    def __init__(self, innerException: System.Exception) -> None: ...

class StoragePermissionException(
    Agilent.OpenLab.Framework.Common.StorageException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, inner: System.Exception) -> None: ...
    @overload
    def __init__(self, innerException: System.Exception) -> None: ...

class WorkAreaDoesNotExistException(
    Agilent.OpenLab.Framework.Common.StorageException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, inner: System.Exception) -> None: ...
    @overload
    def __init__(self, innerException: System.Exception) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Definitions import Command, Tools
from .ToolState import IToolState

# Stubs for namespace: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager

class ActiveDockPaneManager(System.IDisposable):  # Class
    def __init__(
        self, dockMgr: Infragistics.Windows.DockManager.XamDockManager
    ) -> None: ...
    def Dispose(self) -> None: ...

class ApplicationMenu2010(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IApplicationMenu2010
):  # Class
    def __init__(
        self, menu: Infragistics.Windows.Ribbon.ApplicationMenu2010
    ) -> None: ...

    IsOpen: bool
    LastSelectedTabID: str
    SelectedTabID: str

class ContextMenuBridge(System.IDisposable):  # Class
    def __init__(
        self,
        toolManager: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
        control: System.Windows.Forms.Control,
        id: str,
    ) -> None: ...
    @staticmethod
    def Register(
        toolManager: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
        control: System.Windows.Forms.Control,
        contextMenuID: str,
    ) -> None: ...
    def Dispose(self) -> None: ...

class IApplicationMenu2010(object):  # Interface
    IsOpen: bool
    LastSelectedTabID: str
    SelectedTabID: str

class IContextMenuToolState(object):  # Interface
    def SetContextMenu(self, element: System.Windows.FrameworkElement) -> None: ...

class IToolManager(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
):  # Interface
    ApplicationMenu2010: (
        Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IApplicationMenu2010
    )  # readonly
    Command: System.Windows.Input.ICommand  # readonly
    Dispatcher: System.Windows.Threading.Dispatcher  # readonly
    InputBindings: System.Windows.Input.InputBindingCollection  # readonly
    UIState: Any  # readonly

    def GetApplicationMenu2010Content(self, category: str, id: str) -> Any: ...
    def ApplicationMenu2010SelectedTabItemChanged(self) -> None: ...
    def RegisterBeforeToolDropdown(
        self,
        id: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def AddTool(self, cateogry: str, state: IToolState) -> None: ...
    def GetToolImage(self, id: str) -> System.Drawing.Image: ...
    def GetToolbarTitle(self, id: str) -> str: ...
    def RegisterToolHandler(
        self,
        id: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler,
    ) -> None: ...
    def IsContextualTabGroupVisible(self, id: str) -> bool: ...
    def InsertTool(self, id: str, parent: str, after: str) -> None: ...
    def Execute(self, state: IToolState) -> None: ...
    def GetImage(self, image: str) -> System.Windows.Media.Imaging.BitmapSource: ...
    def NotifyContextualTabGroupsChanged(self) -> None: ...
    def GetToolState(self, id: str) -> IToolState: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...
    @overload
    def GetToolCaption(
        self, id: str, culture: System.Globalization.CultureInfo
    ) -> str: ...
    def SetToolState(self, state: IToolState) -> None: ...
    def GetToolTooltip(self, id: str) -> str: ...
    def ApplicationMenu2010Opened(self) -> None: ...
    def NotifyBeforeToolDropdown(
        self,
        state: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    ) -> None: ...
    def ToolInstanceRemoved(self, state: IToolState) -> None: ...
    def ApplicationMenu2010Closed(self) -> None: ...
    def GetToolTooltipTitle(self, id: str) -> str: ...
    def AddToolbar(
        self,
        paneId: str,
        toolbarId: str,
        toolbar: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolbar,
    ) -> None: ...
    def RemoveTool(self, id: str, parent: str) -> None: ...
    def SetupRibbon(self, tools: Tools) -> None: ...

    ContextualTabGroupsChanged: System.EventHandler  # Event

class IToolbar(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbar
):  # Interface
    _ToolBar: System.Windows.Controls.ToolBar  # readonly

class IToolbarHost(object):  # Interface
    def AddToolbar(
        self,
        id: str,
        toolbar: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolbar,
    ) -> None: ...
    def SetFocus(self) -> None: ...
    def GetToolbarIds(self) -> List[str]: ...
    def RemoveToolbar(self, id: str) -> None: ...
    def ContainsToolbar(self, toolbarId: str) -> bool: ...
    def GetToolbar(
        self, id: str
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolbar: ...

class ThreadRequeryCommands(
    System.IDisposable, System.Windows.Forms.IMessageFilter
):  # Class
    def __init__(self) -> None: ...
    def PreFilterMessage(self, m: System.Windows.Forms.Message) -> bool: ...
    def Dispose(self) -> None: ...

class ToolHandlerSet:  # Class
    def __init__(self) -> None: ...
    @overload
    def RegisterCategoryHandler(
        self,
        category: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...
    @overload
    def RegisterCategoryHandler(
        self,
        category: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler,
    ) -> None: ...
    def ContainsCategoryHandler(self, category: str) -> bool: ...
    def RegisterCategory(self, id: str, category: str) -> None: ...
    @overload
    def RegisterToolHandler(
        self,
        id: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...
    @overload
    def RegisterToolHandler(
        self,
        id: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler,
    ) -> None: ...
    def SetToolState(self, tool: IToolState, uiState: Any) -> None: ...
    def GetToolCategory(self, id: str) -> str: ...
    @overload
    def Execute(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...
    @overload
    def Execute(self, tool: IToolState, uiState: Any) -> None: ...

class ToolManagerBase(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
):  # Class
    def __init__(
        self, ribbon: Infragistics.Windows.Ribbon.XamRibbon, uiState: Any
    ) -> None: ...

    ApplicationMenu2010: (
        Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IApplicationMenu2010
    )  # readonly
    Command: System.Windows.Input.ICommand  # readonly
    Dispatcher: System.Windows.Threading.Dispatcher  # readonly
    InputBindings: System.Windows.Input.InputBindingCollection  # readonly
    Ribbon: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbon
    )  # readonly
    TouchEnabled: bool
    UIState: Any  # readonly
    XamRibbon: Infragistics.Windows.Ribbon.XamRibbon  # readonly

    def GetApplicationMenu2010Content(self, category: str, id: str) -> Any: ...
    def ApplicationMenu2010SelectedTabItemChanged(self) -> None: ...
    def RegisterCheckButton(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def RegisterBeforeToolDropdown(
        self,
        id: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def GetApplicationMenu(
        self, paneId: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IApplicationMenu
    ): ...
    def SetToolImage(self, id: str, image: System.Drawing.Image) -> None: ...
    def Dispose(self) -> None: ...
    def RegisterPopupMenu(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def GetToolbarIds(self, pane: str) -> List[str]: ...
    def AddTool(self, category: str, tool: IToolState) -> None: ...
    def InvokeMouseAction(
        self,
        pane: str,
        button: str,
        mact: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.MouseAction,
        state: str,
    ) -> None: ...
    def CreateCommand(self) -> Command: ...
    def GetTool(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def GetToolImage(self, id: str) -> System.Drawing.Image: ...
    def GetTools(
        self, id: str
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool]: ...
    def GetToolbarTitle(self, id: str) -> str: ...
    @overload
    def RegisterToolHandler(
        self,
        id: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...
    @overload
    def RegisterToolHandler(
        self,
        id: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler,
    ) -> None: ...
    def RegisterTool(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def RemoveToolbar(self, paneId: str, toolbarId: str) -> None: ...
    def ContainsTool(self, id: str) -> bool: ...
    def InsertTool(self, id: str, parent: str, after: str) -> None: ...
    def IsContextualTabGroupVisible(self, id: str) -> bool: ...
    @overload
    def Execute(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    ) -> None: ...
    @overload
    def Execute(self, tool: IToolState) -> None: ...
    def RevokeTool(self, id: str) -> None: ...
    def GetImage(self, image: str) -> System.Windows.Media.Imaging.BitmapSource: ...
    def ContainsCategoryHandler(self, category: str) -> bool: ...
    def RegisterLabel(
        self, id: str, category: str, caption: str, tooltip: str
    ) -> None: ...
    def NotifyContextualTabGroupsChanged(self) -> None: ...
    def GetToolState(self, id: str) -> IToolState: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...
    @overload
    def GetToolCaption(
        self, id: str, culture: System.Globalization.CultureInfo
    ) -> str: ...
    def SetToolState(self, state: IToolState) -> None: ...
    def RegisterToolbarHost(
        self,
        paneId: str,
        host: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolbarHost,
    ) -> None: ...
    def GetToolTooltip(self, id: str) -> str: ...
    def RegisterComboBox(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def GetToolbar(
        self, paneId: str, toolbarId: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbar: ...
    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    def ApplicationMenu2010Opened(self) -> None: ...
    def NotifyBeforeToolDropdown(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    ) -> None: ...
    def ToolInstanceRemoved(self, tool: IToolState) -> None: ...
    def ApplicationMenu2010Closed(self) -> None: ...
    def GetToolTooltipTitle(self, id: str) -> str: ...
    @overload
    def AddToolbar(
        self, paneId: str, toolbarId: str, text: str, row: int, column: int
    ) -> None: ...
    @overload
    def AddToolbar(
        self,
        pane: str,
        toolbarId: str,
        toolbar: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolbar,
    ) -> None: ...
    @overload
    def AddToolbar(self, paneId: str, toolbarId: str, text: str) -> None: ...
    @overload
    def RemoveTool(self, id: str) -> None: ...
    @overload
    def RemoveTool(self, id: str, parent: str) -> None: ...
    def SetupRibbon(self, tools: Tools) -> None: ...
    def GetToolCategory(self, id: str) -> str: ...
    def ContainsToolbar(self, paneId: str, toolbarId: str) -> bool: ...
    @overload
    def RegisterCategoryHandler(
        self,
        category: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...
    @overload
    def RegisterCategoryHandler(
        self,
        category: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler,
    ) -> None: ...
    def RegisterButton(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...

    ContextualTabGroupsChanged: System.EventHandler  # Event
    ToolExecuting: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolExecuteEventArgs
    ]  # Event

class ToolbarHost(
    System.Windows.Media.Composition.DUCE.IResource,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolbarHost,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.DockPanel,
    System.ComponentModel.ISupportInitialize,
    System.Windows.IInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.IFrameworkInputElement,
    System.Windows.Input.ICommand,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...

    Host: System.Windows.Forms.Integration.WindowsFormsHost  # readonly

    def AddToolbar(
        self,
        id: str,
        toolbar: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolbar,
    ) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def SetFocus(self) -> None: ...
    def GetToolbarIds(self) -> List[str]: ...
    def RemoveToolbar(self, id: str) -> None: ...
    def Execute(self, parameter: Any) -> None: ...
    def InitializeComponent(self) -> None: ...
    def ContainsToolbar(self, toolbarId: str) -> bool: ...
    def GetToolbar(
        self, id: str
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolbar: ...

    CanExecuteChanged: System.EventHandler  # Event



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Caches, DataHandlers, Extensions, Interfaces, Providers, Utilities

# Discovered Generic TypeVars:
TProvider = TypeVar("TProvider")
TRoot = TypeVar("TRoot")
from .AcamlObjectModel import IACAML
from .Interfaces import DataChangeLevel, IProviderLookupCache

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure

class AsyncFulltextIndexCompletedEvent(
    Agilent.OpenLab.Framework.Common.Notification.InfrastructureEventBase[
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.AsyncFulltextIndexCompletedEventArgs
    ],
    Agilent.OpenLab.Framework.Common.Notification.IInfrastructureEvent,
):  # Class
    def __init__(self) -> None: ...

class AsyncFulltextIndexCompletedEventArgs(System.EventArgs):  # Class
    DocId: System.Guid  # readonly

class AsyncLoadingCompletedEvent(
    Agilent.OpenLab.Framework.Common.Notification.IInfrastructureEvent,
    Agilent.OpenLab.Framework.Common.Notification.InfrastructureEventBase[
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.AsyncLoadingCompletedEventArgs
    ],
):  # Class
    def __init__(self) -> None: ...

class AsyncLoadingCompletedEventArgs(System.EventArgs):  # Class
    AcamlObject: IACAML  # readonly
    DocId: System.Guid  # readonly

class AsyncValidationCompletedEvent(
    Agilent.OpenLab.Framework.Common.Notification.InfrastructureEventBase[
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.AsyncValidationCompletedEventArgs
    ],
    Agilent.OpenLab.Framework.Common.Notification.IInfrastructureEvent,
):  # Class
    def __init__(self) -> None: ...

class AsyncValidationCompletedEventArgs(System.EventArgs):  # Class
    DocId: System.Guid  # readonly
    IsValid: bool  # readonly
    Message: str  # readonly

class DataChangedEventArgs(System.EventArgs):  # Class
    ChangeLevel: DataChangeLevel
    DocId: System.Guid  # readonly

class NotificationService(
    Agilent.OpenLab.Framework.Common.Notification.NotificationServiceBase
):  # Class
    def __init__(self) -> None: ...

    Instance: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.NotificationService
    )  # static # readonly

class ProviderLookupCacheBase(Generic[TRoot, TProvider], IProviderLookupCache):  # Class
    DocId: System.Guid  # readonly

    def DirtyDictionaryCount(self) -> int: ...
    def Reset(self) -> None: ...
    def Clear(self) -> None: ...
    def HasDirtyDictionaries(self) -> bool: ...

class ReadyForDataModificationsEvent(
    Agilent.OpenLab.Framework.Common.Notification.IInfrastructureEvent,
    Agilent.OpenLab.Framework.Common.Notification.InfrastructureEventBase[
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.ReadyForDataModificationsEventArgs
    ],
):  # Class
    def __init__(self) -> None: ...
    def Subscribe(
        self,
        action: System.Action[
            Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.ReadyForDataModificationsEventArgs
        ],
    ) -> None: ...

class ReadyForDataModificationsEventArgs(System.EventArgs):  # Class
    DocId: System.Guid  # readonly

class TraceDataAccess(Agilent.OpenLab.Framework.Diagnostics.TraceBase):  # Class
    TraceSourceNameModule: str = ...  # static # readonly

    Log: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.TraceDataAccess
    )  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataStorageECM.Properties

class Resources:  # Class
    Culture: System.Globalization.CultureInfo  # static
    Exp_AnalysisNotExist: str  # static # readonly
    Exp_BatchFileIsAlreadyLocked: str  # static # readonly
    Exp_BatchFileNotFoundInZip: str  # static # readonly
    Exp_BatchNotExist: str  # static # readonly
    Exp_CannotCreateBatchInThisFolderLevel: str  # static # readonly
    Exp_CannotReadBatchInformation: str  # static # readonly
    Exp_FailedToLogonAsSecureUser: str  # static # readonly
    Exp_FailedToOpenZipFileMayBeCorrupt: str  # static # readonly
    Exp_FileAlreadyCheckedOut: str  # static # readonly
    Exp_FileAlreadyExists: str  # static # readonly
    Exp_FileNotExist: str  # static # readonly
    Exp_InvalidToken: str  # static # readonly
    Exp_LocalFileNotExist: str  # static # readonly
    Exp_LogonFailed: str  # static # readonly
    Exp_LogonFailedRequiredInformationMissing: str  # static # readonly
    Exp_ParameterNotSpecified: str  # static # readonly
    Exp_Permission: str  # static # readonly
    Exp_ReasonRequired: str  # static # readonly
    Exp_RevisionNotExist: str  # static # readonly
    Exp_UserInfoNotMatch: str  # static # readonly
    Exp_ValidUserNameAndPasswordRequired: str  # static # readonly
    FileType_AllFiles: str  # static # readonly
    FileType_BatchFiles: str  # static # readonly
    FileType_LibraryFiles: str  # static # readonly
    FileType_MethodFiles: str  # static # readonly
    FileType_SampleFiles: str  # static # readonly
    FileType_UnknownsAnalysisFiles: str  # static # readonly
    LogonInfo: str  # static # readonly
    Msg_CannotReadZipFile: str  # static # readonly
    Msg_LoggingInPleaseWait: str  # static # readonly
    Msg_PleaseLoginECM: str  # static # readonly
    Progress_Converting: str  # static # readonly
    Progress_Downloading: str  # static # readonly
    Progress_ExtractingFiles: str  # static # readonly
    Prompt_Reset: str  # static # readonly
    ResourceManager: System.Resources.ResourceManager  # static # readonly
    Title_ATMConfiguration: str  # static # readonly
    Title_Login: str  # static # readonly
    Title_NewBatch: str  # static # readonly
    Title_NewUnknownsFile: str  # static # readonly
    Title_OpenBatch: str  # static # readonly
    Title_OpenUnknownsFile: str  # static # readonly
    Title_SaveBatchAs: str  # static # readonly
    Title_SaveUnknownsFileAs: str  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .AppCommand import ApplicationType
from .ScriptIF import IEditView, IMainForm, ITemplatesView, IUIState
from .UI import UIContext, ViewMode
from .Utils import IImportCompounds

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.ScriptIFImpls

class MainForm(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.ScriptIFImpls.ScriptIFImplsBase,
    IMainForm,
    System.Windows.Forms.IWin32Window,
):  # Class
    CurrentView: IEditView  # readonly
    Handle: System.IntPtr  # readonly
    IsInEditMode: bool  # readonly
    TemplatesView: ITemplatesView  # readonly
    ViewMode: ViewMode

class ScriptIFImplsBase(System.MarshalByRefObject):  # Class
    ...

class TemplatesView(
    ITemplatesView,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.ScriptIFImpls.ScriptIFImplsBase,
    IEditView,
):  # Class
    CanCopy: bool  # readonly
    CanCut: bool  # readonly
    CanDelete: bool  # readonly
    CanPaste: bool  # readonly
    CanRedo: Optional[bool]  # readonly
    CanUndo: Optional[bool]  # readonly

    def Redo(self) -> None: ...
    def Undo(self) -> None: ...
    def Copy(self) -> None: ...
    def RemoveTemplates(self) -> None: ...
    def CanRemoveTemplates(self) -> bool: ...
    def Cut(self) -> None: ...
    def Paste(self) -> None: ...
    def Delete(self) -> None: ...

class UIState(
    IUIState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.ScriptIFImpls.ScriptIFImplsBase,
):  # Class
    ApplicationType: ApplicationType  # readonly
    CanRedo: bool  # readonly
    CanUndo: bool  # readonly
    ImportCompounds: IImportCompounds  # readonly
    IsDirty: bool  # readonly
    MainForm: IMainForm  # readonly
    PathName: str  # readonly
    _UIContext: UIContext  # readonly

    def ExecuteCommand(self, name: str, parameters: List[Any]) -> Any: ...
    def Redo(self) -> None: ...
    def Undo(self) -> None: ...
    def ExitApplication(self, forceExit: bool) -> None: ...
